@@ -1,7 +1,7 @@
 package Tree::Dump;
 
-our $DATE = '2016-03-31'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,8 +25,10 @@ sub tdmp {
                     map { ($_ => $node->{$_}) }
                         grep { !/^_?children$/ && !blessed($node->{$_}) }
                             keys %$node });
-            } else {
+            } elsif (reftype($node) eq 'ARRAY') {
                 $res .= dmp([ map { blessed($_) ? "<obj>": $_ } @$node]);
+            } else {
+                $res .= "$node";
             }
             $res;
         },
@@ -56,7 +58,7 @@ Tree::Dump - Dump a tree object
 
 =head1 VERSION
 
-This document describes version 0.02 of Tree::Dump (from Perl distribution Tree-Dump), released on 2016-03-31.
+This document describes version 0.03 of Tree::Dump (from Perl distribution Tree-Dump), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
